# coding: utf-8

"""
    SnapTrade

    Connect brokerage accounts to your app for live positions and trading

    The version of the OpenAPI document: 1.0.0
    Contact: api@snaptrade.com
    Created by: https://snaptrade.com/
"""

from datetime import datetime, date
import typing
from enum import Enum
from typing_extensions import TypedDict, Literal, TYPE_CHECKING

from snaptrade_client.type.option_strategy import OptionStrategy
from snaptrade_client.type.price import Price
from snaptrade_client.type.strategy_quotes_greek import StrategyQuotesGreek

class RequiredStrategyQuotes(TypedDict):
    pass

class OptionalStrategyQuotes(TypedDict, total=False):
    strategy: OptionStrategy

    open_price: Price

    bid_price: Price

    ask_price: Price

    volatility: typing.Union[int, float]

    greek: StrategyQuotesGreek

class StrategyQuotes(RequiredStrategyQuotes, OptionalStrategyQuotes):
    pass
